@@ -10,7 +10,7 @@ TEOIMAGE *U_TeoCreateMagnifyImage (TEOFILE *in, int frame,
 				   float block_size_x, float block_size_y)
 {
   TEOIMAGE	*in_img, *out_img;
-  int 		row, col, mrow, mcol, f, p;
+  int 		row, col, mrow, mcol, p;
   int		rs, re, cs, ce, xoff, yoff;
   
 
